.. COCOPLOT documentation master file, created by
   sphinx-quickstart on Tue Apr  5 17:55:44 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to COCOPLOT's documentation!
====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

Modules
=======

.. toctree::
   :maxdepth: 3

   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
